@@ -146,32 +146,140 @@ class Neo4jHelper:
 
     async def create_node(self, node_name: str, label_name: str, node_property: dict = {}):
         sql = f"CREATE ({node_name}:{label_name} {dict_str(node_property)})"
-        result = await self.execute_fetchall(sql)
+        result = await self.execute_write(sql)
         return result
 
     async def create_node_relationship(self, relationship_list: list):
         sql = f"CREATE "
         sql += ",".join(relationship_list)
-        result = await self.execute_fetchall(sql)
+        result = await self.execute_write(sql)
         return result
 
-    async def delete_node(self, node_list: list):
-        sql = f"DELETE "
-        sql += ",".join(node_list)
-        result = await self.execute_fetchall(sql)
+    async def delete_node(self, node_name: str, label_name: str, match_property_dict: dict = {},
+                          node_property_dict: dict = {}):
+        sql = f"MATCH ({node_name}:{label_name}"
+        if match_property_dict:
+            sql += f"{dict_str(match_property_dict)})"
+        else:
+            sql += ")"
+        if node_property_dict:
+            node_property_str = ",".join(
+                ['%s=%r' % (property_name, property_value) for property_name, property_value in
+                 node_property_dict.items()])
+            sql += f' WHERE {node_property_str}'
+        sql += f" DELETE {node_name}"
+        result = await self.execute_write(sql)
         return result
 
-    async def delete_property(self, node: str, property_node: dict, node_property: str):
-        sql = f"MATCH ({node}:{dict_str(property_node)}) REMOVE {node}.{node_property} RETURN {node}"
-        result = await self.execute_fetchall(sql)
+    async def delete_property(self, node_name: str, label_name: str, delete_node_property_list: list,
+                              match_property_dict: dict = {}, node_property_dict: dict = {}):
+        sql = f"MATCH ({node_name}:{label_name}"
+        if match_property_dict:
+            sql += f"{dict_str(match_property_dict)})"
+        else:
+            sql += ")"
+        if node_property_dict:
+            node_property_str = ",".join(
+                ['%s=%r' % (property_name, property_value) for property_name, property_value in
+                 node_property_dict.items()])
+            sql += f' WHERE {node_property_str}'
+        delete_node_property_str = ','.join([f'{node_name}.{p}' for p in delete_node_property_list])
+        sql += f' REMOVE {delete_node_property_str} RETURN {node_name}'
+        result = await self.execute_write(sql)
         return result
 
-    async def update_node(self, node_name: str, label_name: str, node_property_dict: dict):
+    async def update_node(self, node_name: str, label_name: str, new_node_property_dict: dict,
+                          match_property_dict: dict = {}, node_property_dict: dict = {}):
+        new_node_property_str = ",".join(
+            ['%s.%s=%r' % (node_name, property_name, property_value) for property_name, property_value in
+             new_node_property_dict.items()])
+        sql = f"MATCH ({node_name}:{label_name}"
+        if match_property_dict:
+            sql += f"{dict_str(match_property_dict)})"
+        else:
+            sql += ")"
+        if node_property_dict:
+            node_property_str = ",".join(
+                ['%s=%r' % (property_name, property_value) for property_name, property_value in
+                 node_property_dict.items()])
+            sql += f' WHERE {node_property_str}'
+        sql += f" SET {new_node_property_str} RETURN {node_name}"
+        result = await self.execute_write(sql)
+        return result
+
+    async def delete_two_node_relationship(self, relationship_name: str, relationship: str, node1_name: str = None,
+                                           label1_name: str = None, node1_match_property_dict: dict = {},
+                                           node2_name: str = None, label2_name: str = None,
+                                           node2_match_property_dict: dict = {}):
+        if node1_name:
+            if label1_name and not node1_match_property_dict:
+                sql = f'MATCH ({node1_name}:{label1_name}'
+            elif node1_match_property_dict and not label1_name:
+                sql = f'MATCH ({node1_name} {dict_str(node1_match_property_dict)}'
+            elif node1_match_property_dict and label1_name:
+                sql = f'MATCH ({node1_name}:{label1_name} {dict_str(node1_match_property_dict)}'
+            else:
+                raise Exception("At least one of label_name and match_property_dict")
+            sql += ")"
+        else:
+            if label1_name and not node1_match_property_dict:
+                sql = f'MATCH ({label1_name}'
+            elif node1_match_property_dict and label1_name:
+                sql = f'MATCH ({label1_name} {dict_str(node1_match_property_dict)}'
+            else:
+                raise Exception("At least one of label_name and node_name")
+            sql += ")"
+        node2_str = f'('
+        if node2_name:
+            if label2_name and not node2_match_property_dict:
+                node2_str += f'{node2_name}:{label2_name}'
+            elif node2_match_property_dict and not label2_name:
+                node2_str += f'{node2_name} {dict_str(node2_match_property_dict)}'
+            elif node2_match_property_dict and label2_name:
+                node2_str += f'{node2_name}:{label2_name} {dict_str(node2_match_property_dict)}'
+            else:
+                raise Exception("At least one of label_name and match_property_dict")
+        else:
+            if label2_name and not node2_match_property_dict:
+                node2_str += f'{label2_name}'
+            elif node2_match_property_dict and label2_name:
+                node2_str += f'{label2_name} {dict_str(node2_match_property_dict)}'
+            else:
+                raise Exception("At least one of label_name and node_name")
+        node2_str += ')'
+        sql += f'{relationship}{node2_str} DELETE {relationship_name}'
+        result = await self.execute_write(sql)
+        return result
+
+    async def delete_node_and_all_relationship(self, node_name: str = None, label_name: str = None,
+                                               match_property_dict: dict = {},
+                                               node_property_dict: dict = {}):
+        if node_name:
+            if label_name and not match_property_dict:
+                sql = f'MATCH ({node_name}:{label_name})'
+            elif match_property_dict and not label_name:
+                sql = f'MATCH ({node_name} {dict_str(match_property_dict)})'
+            elif match_property_dict and label_name:
+                sql = f'MATCH ({node_name}:{label_name} {dict_str(match_property_dict)})'
+            else:
+                raise Exception("At least one of label_name and match_property_dict")
+        else:
+            if label_name and not match_property_dict:
+                sql = f'MATCH ({label_name})'
+            elif match_property_dict and label_name:
+                sql = f'MATCH ({label_name} {dict_str(match_property_dict)})'
+            else:
+                raise Exception("At least one of label_name and node_name")
         node_property_str = ",".join(
             ['%s=%r' % (property_name, property_value) for property_name, property_value in
              node_property_dict.items()])
-        sql = f"MATCH ({node_name}:{label_name}) SET {node_property_str} RETURN {node_name}"
-        result = await self.execute_fetchall(sql)
+        if node_property_str:
+            sql += f' WHERE {node_property_str}'
+        if node_name:
+            sql += f" DETACH DELETE {node_name}"
+        else:
+            sql += f" DETACH DELETE {label_name}"
+        result = await self.execute_write(sql)
         return result
 
     async def query_node_relationship(self, relationship: str, node1_name: str = None, label1_name: str = None,
@@ -235,7 +343,7 @@ class Neo4jHelper:
         results = await self.pool.read_transaction(self.query_work, sql)
         records = []
         for record in results:
-            records.append(record.data())
+            records.append(parse_record(record, flag=True))
         return records
 
     async def query_all_node(self, node_name: str = None, label_name: str = None, match_property_dict: dict = {},
@@ -271,7 +379,7 @@ class Neo4jHelper:
         results = await self.pool.read_transaction(self.query_work, sql)
         records = []
         for record in results:
-            records.append(record.data())
+            records.append(parse_record(record, flag=False))
         return records
 
     async def query_node_count(self, node_name: str = None, label_name: str = None, match_property_dict: dict = {},
@@ -339,20 +447,28 @@ class Neo4jHelper:
         results = await self.pool.read_transaction(self.query_work, sql)
         records = []
         for record in results:
-            records.append(record.data())
+            records.append(parse_record(record, flag=False))
         return Page(records=records, current=page_num, page_size=page_size, total=total).__dict__
 
-    async def execute_fetchall(self, sql):
+    async def execute_fetchall(self, sql, flag=True):
         results = await self.pool.read_transaction(self.query_work, sql)
         records = []
         for record in results:
-            records.append(record.data())
+            records.append(parse_record(record, flag=flag))
         return records
 
     async def query_work(self, tx, sql):
         result = await tx.run(sql)
         return [record async for record in result]
 
+    async def write_work(self, tx, sql):
+        result = await tx.run(sql)
+        return await result.consume()
+
+    async def execute_write(self, sql):
+        summary = await self.pool.write_transaction(self.sync_write_work, sql)
+        return eval(summary.counters.__repr__())
+
     def sync_listreader(self, cypher, keys):
         """
         Read data from Neo4j in specified cypher.
@@ -462,54 +578,165 @@ class Neo4jHelper:
 
     def sync_create_node(self, node_name: str, label_name: str, node_property: dict = {}):
         sql = f"CREATE ({node_name}:{label_name} {dict_str(node_property)})"
-        result = self.sync_execute_fetchall(sql)
+        result = self.sync_execute_write(sql)
         return result
 
     def sync_create_node_relationship(self, relationship_list: list):
         sql = f"CREATE "
         sql += ",".join(relationship_list)
-        result = self.sync_execute_fetchall(sql)
+        result = self.sync_execute_write(sql)
         return result
 
-    def sync_delete_node(self, node_list: list):
-        sql = f"DELETE "
-        sql += ",".join(node_list)
-        result = self.sync_execute_fetchall(sql)
+    def sync_delete_node(self, node_name: str, label_name: str, match_property_dict: dict = {},
+                         node_property_dict: dict = {}):
+        sql = f"MATCH ({node_name}:{label_name}"
+        if match_property_dict:
+            sql += f"{dict_str(match_property_dict)})"
+        else:
+            sql += ")"
+        if node_property_dict:
+            node_property_str = ",".join(
+                ['%s=%r' % (property_name, property_value) for property_name, property_value in
+                 node_property_dict.items()])
+            sql += f' WHERE {node_property_str}'
+        sql += f" DELETE {node_name}"
+        result = self.sync_execute_write(sql)
         return result
 
-    def sync_delete_property(self, node: str, property_node: dict, node_property: str):
-        sql = f"MATCH ({node}:{dict_str(property_node)}) REMOVE {node}.{node_property} RETURN {node}"
-        result = self.sync_execute_fetchall(sql)
+    def sync_delete_property(self, node_name: str, label_name: str, delete_node_property_list: list,
+                             match_property_dict: dict = {}, node_property_dict: dict = {}):
+        sql = f"MATCH ({node_name}:{label_name}"
+        if match_property_dict:
+            sql += f"{dict_str(match_property_dict)})"
+        else:
+            sql += ")"
+        if node_property_dict:
+            node_property_str = ",".join(
+                ['%s=%r' % (property_name, property_value) for property_name, property_value in
+                 node_property_dict.items()])
+            sql += f' WHERE {node_property_str}'
+        delete_node_property_str = ','.join([f'{node_name}.{p}' for p in delete_node_property_list])
+        sql += f' REMOVE {delete_node_property_str} RETURN {node_name}'
+        result = self.sync_execute_write(sql)
         return result
 
-    def sync_update_node(self, node_name: str, label_name: str, node_property_dict: dict):
+    def sync_update_node(self, node_name: str, label_name: str, new_node_property_dict: dict,
+                         match_property_dict: dict = {}, node_property_dict: dict = {}):
+        new_node_property_str = ",".join(
+            ['%s.%s=%r' % (node_name, property_name, property_value) for property_name, property_value in
+             new_node_property_dict.items()])
+        sql = f"MATCH ({node_name}:{label_name}"
+        if match_property_dict:
+            sql += f"{dict_str(match_property_dict)})"
+        else:
+            sql += ")"
+        if node_property_dict:
+            node_property_str = ",".join(
+                ['%s=%r' % (property_name, property_value) for property_name, property_value in
+                 node_property_dict.items()])
+            sql += f' WHERE {node_property_str}'
+        sql += f" SET {new_node_property_str} RETURN {node_name}"
+        result = self.sync_execute_write(sql)
+        return result
+
+    def sync_delete_two_node_relationship(self, relationship_name: str, relationship: str, node1_name: str = None,
+                                          label1_name: str = None, node1_match_property_dict: dict = {},
+                                          node2_name: str = None, label2_name: str = None,
+                                          node2_match_property_dict: dict = {}):
+        if node1_name:
+            if label1_name and not node1_match_property_dict:
+                sql = f'MATCH ({node1_name}:{label1_name}'
+            elif node1_match_property_dict and not label1_name:
+                sql = f'MATCH ({node1_name} {dict_str(node1_match_property_dict)}'
+            elif node1_match_property_dict and label1_name:
+                sql = f'MATCH ({node1_name}:{label1_name} {dict_str(node1_match_property_dict)}'
+            else:
+                raise Exception("At least one of label_name and match_property_dict")
+            sql += ")"
+        else:
+            if label1_name and not node1_match_property_dict:
+                sql = f'MATCH ({label1_name}'
+            elif node1_match_property_dict and label1_name:
+                sql = f'MATCH ({label1_name} {dict_str(node1_match_property_dict)}'
+            else:
+                raise Exception("At least one of label_name and node_name")
+            sql += ")"
+        node2_str = f'('
+        if node2_name:
+            if label2_name and not node2_match_property_dict:
+                node2_str += f'{node2_name}:{label2_name}'
+            elif node2_match_property_dict and not label2_name:
+                node2_str += f'{node2_name} {dict_str(node2_match_property_dict)}'
+            elif node2_match_property_dict and label2_name:
+                node2_str += f'{node2_name}:{label2_name} {dict_str(node2_match_property_dict)}'
+            else:
+                raise Exception("At least one of label_name and match_property_dict")
+        else:
+            if label2_name and not node2_match_property_dict:
+                node2_str += f'{label2_name}'
+            elif node2_match_property_dict and label2_name:
+                node2_str += f'{label2_name} {dict_str(node2_match_property_dict)}'
+            else:
+                raise Exception("At least one of label_name and node_name")
+        node2_str += ')'
+        sql += f'{relationship}{node2_str} DELETE {relationship_name}'
+        result = self.sync_execute_write(sql)
+        return result
+
+    def sync_delete_node_and_all_relationship(self, node_name: str = None, label_name: str = None,
+                                              match_property_dict: dict = {},
+                                              node_property_dict: dict = {}):
+        if node_name:
+            if label_name and not match_property_dict:
+                sql = f'MATCH ({node_name}:{label_name})'
+            elif match_property_dict and not label_name:
+                sql = f'MATCH ({node_name} {dict_str(match_property_dict)})'
+            elif match_property_dict and label_name:
+                sql = f'MATCH ({node_name}:{label_name} {dict_str(match_property_dict)})'
+            else:
+                raise Exception("At least one of label_name and match_property_dict")
+        else:
+            if label_name and not match_property_dict:
+                sql = f'MATCH ({label_name})'
+            elif match_property_dict and label_name:
+                sql = f'MATCH ({label_name} {dict_str(match_property_dict)})'
+            else:
+                raise Exception("At least one of label_name and node_name")
         node_property_str = ",".join(
             ['%s=%r' % (property_name, property_value) for property_name, property_value in
              node_property_dict.items()])
-        sql = f"MATCH ({node_name}:{label_name}) SET {node_property_str} RETURN {node_name}"
-        result = self.sync_execute_fetchall(sql)
+        if node_property_str:
+            sql += f' WHERE {node_property_str}'
+        if node_name:
+            sql += f" DETACH DELETE {node_name}"
+        else:
+            sql += f" DETACH DELETE {label_name}"
+        result = self.sync_execute_write(sql)
         return result
 
     def sync_query_node_relationship(self, relationship: str, node1_name: str = None, label1_name: str = None,
                                      node1_match_property_dict: dict = {},
                                      property_dict: dict = {}, node2_name: str = None, label2_name: str = None,
-                                     node2_match_property_dict: dict = {}, result_list: list = None):
+                                     node2_match_property_dict: dict = {},
+                                     result_list: list = None):
         if node1_name:
             if label1_name and not node1_match_property_dict:
-                sql = f'MATCH ({node1_name}:{label1_name})'
+                sql = f'MATCH ({node1_name}:{label1_name}'
             elif node1_match_property_dict and not label1_name:
-                sql = f'MATCH ({node1_name} {dict_str(node1_match_property_dict)})'
+                sql = f'MATCH ({node1_name} {dict_str(node1_match_property_dict)}'
             elif node1_match_property_dict and label1_name:
-                sql = f'MATCH ({node1_name}:{label1_name} {dict_str(node1_match_property_dict)})'
+                sql = f'MATCH ({node1_name}:{label1_name} {dict_str(node1_match_property_dict)}'
             else:
                 raise Exception("At least one of label_name and match_property_dict")
+            sql += ")"
         else:
             if label1_name and not node1_match_property_dict:
-                sql = f'MATCH ({label1_name})'
+                sql = f'MATCH ({label1_name}'
             elif node1_match_property_dict and label1_name:
-                sql = f'MATCH ({label1_name} {dict_str(node1_match_property_dict)})'
+                sql = f'MATCH ({label1_name} {dict_str(node1_match_property_dict)}'
             else:
                 raise Exception("At least one of label_name and node_name")
+            sql += ")"
         node2_str = f'('
         if node2_name:
             if label2_name and not node2_match_property_dict:
@@ -551,7 +778,7 @@ class Neo4jHelper:
         results = self.pool.read_transaction(self.sync_query_work, sql)
         records = []
         for record in results:
-            records.append(record.data())
+            records.append(parse_record(record, flag=True))
         return records
 
     def sync_query_all_node(self, node_name: str = None, label_name: str = None, match_property_dict: dict = {},
@@ -587,7 +814,7 @@ class Neo4jHelper:
         results = self.pool.read_transaction(self.sync_query_work, sql)
         records = []
         for record in results:
-            records.append(record.data())
+            records.append(parse_record(record, flag=False))
         return records
 
     def sync_query_node_count(self, node_name: str = None, label_name: str = None, match_property_dict: dict = {},
@@ -654,19 +881,26 @@ class Neo4jHelper:
         results = self.pool.read_transaction(self.sync_query_work, sql)
         records = []
         for record in results:
-            records.append(record.data())
+            records.append(parse_record(record, flag=False))
         return Page(records=records, current=page_num, page_size=page_size, total=total).__dict__
 
     def sync_query_work(self, tx, sql):
         return list(tx.run(sql))
 
-    def sync_execute_fetchall(self, sql):
+    def sync_execute_fetchall(self, sql, flag=True):
         results = self.pool.read_transaction(self.sync_query_work, sql)
         records = []
         for record in results:
-            records.append(record.data())
+            records.append(parse_record(record, flag=flag))
         return records
 
+    def sync_write_work(self, tx, sql):
+        return tx.run(sql).consume()
+
+    def sync_execute_write(self, sql):
+        summary = self.pool.write_transaction(self.sync_write_work, sql)
+        return eval(summary.counters.__repr__())
+
 
 def parse_relation_item(item, id_key, name_key, level=0):
     relation_item = {"start_node": parse_node_dict(item.start_node, id_key, name_key),
@@ -696,3 +930,40 @@ def dict_str(data: dict):
         ls.append('%s:%r' % (k, v))
     string = '{' + ','.join(ls) + '}'
     return string
+
+
+def node2dict(node: neo4j.data.Node):
+    return {"id": node.id, "labels": list(node.labels), "properties": node._properties}
+
+
+def relationship2dict(relationship: neo4j.data.Relationship):
+    return {"start_node": node2dict(relationship.start_node), "end_node": node2dict(relationship.end_node),
+            "id": relationship.id,
+            "type": relationship.type, "properties": relationship._properties}
+
+
+def parse_record(record: neo4j.data.Record, flag=True):
+    _record = {"node": [], "relationship": []}
+    if isinstance(record, neo4j.data.Record):
+        for rd in record:
+            if isinstance(rd, neo4j.data.Node):
+                _record["node"].append(node2dict(rd))
+            elif issubclass(rd.__class__, neo4j.data.Node):
+                _record["node"].append(node2dict(rd))
+            elif isinstance(rd, neo4j.data.Relationship):
+                _record["relationship"].append(relationship2dict(rd))
+            elif issubclass(rd.__class__, neo4j.data.Relationship):
+                _record["relationship"].append(relationship2dict(rd))
+            elif isinstance(rd, list) or isinstance(rd, tuple):
+                for x in rd:
+                    if isinstance(x, neo4j.data.Node):
+                        _record["node"].append(node2dict(x))
+                    elif issubclass(x.__class__, neo4j.data.Node):
+                        _record["node"].append(node2dict(x))
+                    elif isinstance(x, neo4j.data.Relationship):
+                        _record["relationship"].append(relationship2dict(x))
+                    elif issubclass(x.__class__, neo4j.data.Relationship):
+                        _record["relationship"].append(relationship2dict(x))
+    if not flag:
+        _record.pop("relationship")
+    return _record
