@@ -31,7 +31,13 @@ def format_es_param_result(r, param_list, is_need_decrypt_oralce, is_need_es_sco
             for key in key_list:
                 if isinstance(value, list):
                     if value:
-                        value = [v.get(key, None) for v in value]
+                        result = []
+                        for v in value:
+                            if isinstance(v.get(key, None), list):
+                                result = result + v[key]
+                            else:
+                                result.append(v.get(key, None))
+                        value = result
                 elif isinstance(value, dict):
                     if value:
                         value = value.get(key, None)
