@@ -20,9 +20,12 @@ class StatusCode:
 
     # *响应服务请求的状态码与说明
 
+    # 通用状态码
     SUCCESS = ("00000", "请求成功")
     FAIL = ("99999", "请求失败")
+    # A00开头的状态码
     USER_VALIDATE_FAIL = ("A0001", "用户端错误")
+    # A01开头的状态码
     USER_REGISTER_FAIL = ("A0100", "用户注册错误")
     USER_NAME_VALIDATE_FAIL = ("A0110", "用户名校验失败")
     USER_NAME_EXIST = ("A0111", "用户名已存在")
@@ -32,13 +35,15 @@ class StatusCode:
     PASSWORD_LENGTH_VALID = ("A0121", "密码长度不够")
     SHORT_MESSAGE_VALID_FAIL = ("A0130", "短信验证码错误")
     VALIDATE_CODE_ERROR = ("A0131", "验证码错误！")
+    # A02开头的状态码
     USER_LOGIN_EXCEPTION = ("A0200", "用户登录异常")
     USER_ACCOUNT_NOT_EXIST = ("A0201", "用户不存在")
     USER_ACCOUNT_EXPIRE = ("A0202", "账号已失效，请联系管理员！")
     USER_ACCOUNT_PASSWORD_EXPIRE = ("A0203", "密码已失效，请修改密码，重新登录")
     USER_ACCOUNT_EXCEEDED_ERRORS = ("A0204", "密码错误次数过多，账号已锁定，请稍后重试")
     USER_ACCOUNT_DORMANCY = ("A0205", "账号处于休眠状态，请联系管理员！")
-
+    USER_NOT_LOGIN_IN = ("A0206", "用户未登录")
+    # A03开头的状态码
     REQUEST_PARAM_ERROR = ("A0300", "用户请求参数错误")
     INVALID_USER_INPUT = ("A0301", "无效的用户输入")
     INSECURE_TRANSPORT_ERROR = ("A0302", "OAuth 2 必须使用 https.")
@@ -58,8 +63,12 @@ class StatusCode:
     MISMATCHING_STATE_EXCEPTION = ("A0316", "CSRF告警！请求和响应中的状态不相等")
     INVALID_TOKEN = ("A0317", "token已失效")
     FREQUENCY_LIMIT = ("A0318", "请求次数超限")
+    WEIXIN_UNBOUND = ("A0319", "微信未绑定")
+    WEIXIN_BOUNDED = ("A0320", "微信已绑定")
+    INVALID_TIME_STAMP = ("A0321", "非法的时间戳参数")
+    USER_INPUT_INVALID = ("A0322", "用户输入内容非法")
+    UNSUPPORTED_SERVICE_TYPE_ERROR = ("A0323", "不支持的服务类型")
 
-    # REQUIRED_PARAM_IS_EMPTY = ("A0310", "请求缺少必要参数:{}")
     @staticmethod
     def REQUIRED_PARAM_IS_EMPTY(message):
         """
@@ -67,17 +76,18 @@ class StatusCode:
         :param message: 替换的消息内容
         :return:
         """
-        return "A0320", "请求缺少必要参数:{}".format(message)
+        return "A0399", "请求缺少必要参数:{}".format(message)
 
-    INVALID_TIME_STAMP = ("A0321", "非法的时间戳参数")
-    USER_INPUT_INVALID = ("A0322", "用户输入内容非法")
+    # A04开头的状态码
     VALIDATE_CODE_EXPIRE = ("A0400", "验证码过期")
     FORM_VALIDATE_FAIL = ("A0401", "表单校验失败")
     PARAM_VALIDATE_FAIL = ("A0402", "参数校验失败")
     PARAM_BIND_FAIL = ("A0403", "参数绑定失败")
     PHONE_NUM_NOT_FOUND = ("A0404", "找不到该用户，手机号码有误")
 
-    # BUSINESS_FAIL = ("B0000", "{}")
+    # A05开头的状态码
+
+    # B00开头的状态码
     @staticmethod
     def BUSINESS_FAIL(message):
         """
@@ -90,10 +100,17 @@ class StatusCode:
     ACCESS_DENIED = ("B0001", "访问权限不足")
     RESOURCE_DISABLED = ("B0002", "资源被禁用")
     RESOURCE_NO_AUTHORITY = ("B0003", "该资源未定义访问权限")
+
+    # B01开头的状态码
+    TIMEOUT = ("B0100", "系统执行超时")
+    # B02开头的状态码
+    STRIKE_RECOVERY = ("B0200", "系统容灾系统被触发")
+    # B03开头的状态码
+
+    # B04开头的状态码
     RESOURCE_NOT_FOUND = ("B0404", "访问资源不存在")
 
-    # INTERNAL_SERVER_ERROR = ("B0500", "服务器内部错误:{}")
-
+    # B05开头的状态码
     @staticmethod
     def INTERNAL_SERVER_ERROR(message):
         """
@@ -103,7 +120,6 @@ class StatusCode:
         """
         return "B0500", "服务器内部错误:{}".format(message)
 
-    # RESOURCE_EXIST = ("B0501", "{}已存在,确保唯一性，不可重复")
     @staticmethod
     def RESOURCE_EXIST(message):
         """
@@ -113,8 +129,17 @@ class StatusCode:
         """
         return "B0501", "{}已存在,确保唯一性，不可重复".format(message)
 
-    TIMEOUT = ("B0100", "系统执行超时")
-    STRIKE_RECOVERY = ("B0200", "系统容灾系统被触发")
+    # C00开头的状态码
     RPC_INVOKE_ERROR = ("C0001", "调用第三方服务出错")
     SERVER_ERROR = ("C0002", "服务器内部错误")
     UNKNOWN_ERROR = ("C0003", "未知异常")
+
+    # C01开头的状态码
+
+    # C02开头的状态码
+
+    # C03开头的状态码
+
+    # C04开头的状态码
+
+    # C05开头的状态码
